---

slug: /overview-of-character-set-and-collation
---

# Overview

A character set is a set of symbols and their encodings. A collation is a set of rules for comparing characters in a character set.

seekdb supports the following character set and collation features:

* Store strings in various character sets.

* Compare strings in various collations.

* Mix strings with different character sets or collations in the same server, database, or table.

* Enable character set and collation specifications at the database, table, or column level.